searchData={"content_type":"text/markdown","items":[{"doc":"StripJs is an Elixir module for stripping executable JavaScript from\nblocks of HTML and CSS, based on the  Floki  parsing library.\n\nIt handles:\n\n* ` ... ` and `  ` tags\n* Event handler attributes such as `onclick=\"...\"`\n* `javascript:...` URLs in HTML and CSS\n* CSS `expression(...)` directives\n* HTML entity attacks (like `&lt;script&gt;`)\n\nStripJs is production ready, and has sanitized over 1.5 billion payloads\nat Appcues.","ref":"StripJs.html","title":"StripJs","type":"module"},{"doc":"Add `strip_js` to your application's `mix.exs`:\n\n    def application do\n      [applications: [:strip_js]]\n    end\n\n    def deps do\n      [{:strip_js, \"~> #{StripJs.Mixfile.project()[:version]}\"}]\n    end","ref":"StripJs.html#module-installation","title":"Installation - StripJs","type":"module"},{"doc":"`clean_html/2` removes all JS vectors from an HTML string:\n\n    iex> html = \" Hi! \"\n    iex> StripJs.clean_html(html)\n    \" Hi! \"\n\n`clean_css/2` removes all JS vectors from a CSS string:\n\n    iex> css = \"body { background-image: url('javascript:alert()'); }\"\n    iex> StripJs.clean_css(css)\n    \"body { background-image: url('removed_by_strip_js:alert()'); }\"\n\nStripJs relies on the [Floki](https://github.com/philss/floki)\nHTML parser library, which is built using\n[Mochiweb](https://github.com/mochi/mochiweb) by default.\nStripJs provides a `clean_html_tree/1` function to strip JS from\n`Floki.parse_fragment/1`- and `:mochiweb_html.parse/1`- style HTML parse trees.","ref":"StripJs.html#module-usage","title":"Usage - StripJs","type":"module"},{"doc":"StripJs blocks every JS injection vector known to the authors. It has\nsurvived four years in production, multiple professional penetration\ntests, and over a billion invocations with no known security issues.\n\nIf you believe there are JS injection methods not covered by this library,\nplease submit an issue with a test case!","ref":"StripJs.html#module-security","title":"Security - StripJs","type":"module"},{"doc":"The brokenness of invalid HTML may be amplified by `clean_html/2`.\n\nIn uncommon cases, innocent CSS which very closely resembles\nJS-injection techniques may be mangled by `clean_css/2`.","ref":"StripJs.html#module-bugs-and-limitations","title":"Bugs and Limitations - StripJs","type":"module"},{"doc":"Copyright 2017-2021, Appcues, Inc.\n\nProject homepage:\n[StripJs](https://github.com/appcues/strip_js)\n\nStripJs is released under the\n[MIT License](https://opensource.org/licenses/MIT).","ref":"StripJs.html#module-authorship-and-license","title":"Authorship and License - StripJs","type":"module"},{"doc":"Removes JS vectors from the given CSS string; i.e., the contents of a\nstylesheet or ` ` tag.\n\nDoes not HTML-escape its output.  Care is taken to maintain valid CSS\nsyntax.\n\nExample:\n\n    iex> css = \"tt { background-color: expression('alert()'); }\"\n    iex> StripJs.clean_css(css)\n    \"tt { background-color: removed_by_strip_js('alert()'); }\"\n\nWarning: this step is performed using regexes, not a parser, so it is\npossible for innocent CSS containing either of the strings `javascript:`\nor `expression(` to be mangled.","ref":"StripJs.html#clean_css/2","title":"StripJs.clean_css/2","type":"function"},{"doc":"Removes JS vectors from the given HTML string.\n\nAll non-tag text and tag attribute values will be HTML-escaped, except\nfor the contents of ` ` tags, which are passed through `clean_css/2`.\n\nEven if the input HTML contained no JS, the output of `clean_html/2`\nis not guaranteed to match its input byte-for-byte.\n\nExamples:\n\n    iex> StripJs.clean_html(\" Click here \")\n    \" Click here \"\n\n    iex> StripJs.clean_html(\"  console.log('oh heck');  \")\n    \"\"\n\n    iex> StripJs.clean_html(\"&lt;script&gt; console.log('oh heck'); &lt;/script&gt;\")\n    \"&lt;script&gt; console.log('oh heck'); &lt;/script&gt;\"","ref":"StripJs.html#clean_html/2","title":"StripJs.clean_html/2","type":"function"},{"doc":"","ref":"StripJs.html#clean_html/2-html-entity-attack-didn-t-work","title":"HTML entity attack didn't work - StripJs.clean_html/2","type":"function"},{"doc":"Removes JS vectors from the given\n[Floki](https://github.com/philss/floki)/\n[Mochiweb](https://github.com/mochi/mochiweb)-style HTML tree\n(`t:html_tree/0`).\n\nAll attribute values and tag bodies except embedded stylesheets\nwill be HTML-escaped.","ref":"StripJs.html#clean_html_tree/2","title":"StripJs.clean_html_tree/2","type":"function"},{"doc":"","ref":"StripJs.html#t:html_attr/0","title":"StripJs.html_attr/0","type":"type"},{"doc":"","ref":"StripJs.html#t:html_node/0","title":"StripJs.html_node/0","type":"type"},{"doc":"","ref":"StripJs.html#t:html_tag/0","title":"StripJs.html_tag/0","type":"type"},{"doc":"","ref":"StripJs.html#t:html_tree/0","title":"StripJs.html_tree/0","type":"type"},{"doc":"","ref":"StripJs.html#t:opts/0","title":"StripJs.opts/0","type":"type"}],"producer":{"name":"ex_doc","version":"0.33.0"},"proglang":"elixir"}